@@ -46,6 +46,8 @@ MB = 1024 * 1024
 GB = 1024 * MB
 TB = 1024 * GB
 
+version = '0.0.2'
+
 class S3Facts:
     amz_metadata_prefix = 'x-amz-meta-'
     maximum_file_size = 5 * TB
@@ -209,11 +211,12 @@ class CopyS3Request(S3Request):
         else:
             result = r.reason 
         
-        error = '' if ok else 'unable to COPY %s to %s: %i %s' % (
+        error = '' if ok else 'unable to COPY %s to %s: %i %s: %s' % (
                 remote_src,
                 self.url,
                 r.status_code,
-                result)
+                result,
+                r.text)
         return S3Response(ok=ok, error=error, response=r)
 
 class DeleteS3Request(S3Request): 
@@ -233,10 +236,11 @@ class DeleteS3Request(S3Request):
                 self.url,
                 auth=self.auth)
         ok = r.status_code == 204
-        error = r.reason if ok else 'unable to DELETE %s: %i %s' % (
+        error = r.reason if ok else 'unable to DELETE %s: %i %s: %s' % (
                 self.url,
                 r.status_code,
-                r.reason)
+                r.reason,
+                r.text)
         return S3Response(ok=ok, error=error, response=r)
         
 class ExistsS3Request(S3Request): 
@@ -263,10 +267,11 @@ class ExistsS3Request(S3Request):
             error = r.reason
         else:
             ok = False
-            error = 'unable to HEAD %s: %i %s' % (
+            error = 'unable to HEAD %s: %i %s: %s' % (
                     self.url, 
                     r.status_code, 
-                    r.reason)
+                    r.reason,
+                    r.text)
         metadata = self._get_metadata(r.headers)
         return S3Response(ok=ok, error=error, response=r, metadata=metadata)
         
@@ -293,10 +298,11 @@ class ReadS3Request(S3Request):
         for x in r.iter_content(chunk_size=self.part_size):
             self.fp.write(x)
         ok = r.status_code == 200
-        error = r.reason if ok else 'unable to GET %s: %i %s' % (
+        error = r.reason if ok else 'unable to GET %s: %i %s: %s' % (
                 self.url,
                 r.status_code,
-                r.reason)
+                r.reason,
+                r.text)
         metadata = self._get_metadata(r.headers)
         return S3Response(ok=ok, error=error, response=r, metadata=metadata)
 
@@ -422,9 +428,10 @@ class WriteS3Request(S3Request):
                 auth=self.auth)
         logging.info('\n' + data)
         if r.status_code != 200:
-            raise Exception, "Unable to CompleteMultipartUpload: %s %s" % (
+            raise Exception, "Unable to CompleteMultipartUpload: %s %s: %s" % (
                 r.status_code,
-                r.reason)
+                r.reason,
+                r.text)
         logging.info('Upload of %s %s.' % (self.url, r.reason))
         return S3Response(
                 r.status_code == 200, 
@@ -444,10 +451,11 @@ class WriteS3Request(S3Request):
             error = ''
         else:
             ok = False
-            error = 'unable to PUT %s: %i %s' % (
+            error = 'unable to PUT %s: %i %s: %s' % (
                     self.url, 
                     r.status_code, 
-                    r.reason)
+                    r.reason,
+                    r.text)
         return S3Response(
                 ok=ok, 
                 error=error, 
@@ -486,9 +494,10 @@ class WriteS3Request(S3Request):
         except Exception, e:
             raise Exception, "Unable to PUT.  Exception: %s" % e
         if r.status_code != 200:
-            raise Exception, "Unable to PUT (upload part): %s %s" % (
+            raise Exception, "Unable to PUT (upload part): %s %s: %s" % (
                     r.status_code, 
-                    r.reason, )
+                    r.reason, 
+                    r.text)
 
         s3_part = S3Part(self.part_number, r.headers['Etag'])
         self.parts.append(s3_part)
